@@ -1,4 +1,5 @@
 from dataclasses import dataclass
+from typing import Optional
 
 from soundcloud.resource.base import BaseData
 
@@ -7,7 +8,4 @@ class WebProfile(BaseData):
     url: str
     network: str
     title: str
-    
-@dataclass
-class WebProfileUsername(WebProfile):
-    username: str
\ No newline at end of file
+    username: Optional[str]
\ No newline at end of file
